"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const socket_1 = __importDefault(require("./socket"));
const commands_queue_1 = __importStar(require("./commands-queue"));
const commands_1 = __importDefault(require("./commands"));
const multi_command_1 = __importDefault(require("./multi-command"));
const events_1 = __importDefault(require("events"));
const command_options_1 = require("./command-options");
class RedisClient extends events_1.default {
    static defineCommand(on, name, command) {
        on[name] = async function (...args) {
            const options = command_options_1.isCommandOptions(args[0]) && args[0];
            return command.transformReply(await this.sendCommand(command.transformArguments(...(options ? args.slice(1) : args)), options));
        };
    }
    static create(options) {
        return new RedisClient(options);
    }
    static commandOptions(options) {
        return command_options_1.commandOptions(options);
    }
    #options;
    #socket;
    #queue;
    #Multi;
    #modern = {};
    #selectedDB = 0;
    get options() {
        return this.#options;
    }
    get isOpen() {
        return this.#socket.isOpen;
    }
    get modern() {
        if (!this.#options?.legacyMode) {
            throw new Error('the client is not in "legacy mode"');
        }
        return this.#modern;
    }
    constructor(options) {
        super();
        this.#options = options;
        this.#socket = this.#initiateSocket();
        this.#queue = this.#initiateQueue();
        this.#Multi = this.#initiateMulti();
        this.#initiateModules();
        this.#initiateScripts();
        this.#legacyMode();
    }
    #initiateSocket() {
        const socketInitiator = async () => {
            const promises = [];
            if (this.#selectedDB !== 0) {
                promises.push(this.select(RedisClient.commandOptions({ asap: true }), this.#selectedDB));
            }
            if (this.#options?.readonly) {
                promises.push(this.readonly(RedisClient.commandOptions({ asap: true })));
            }
            if (this.#options?.socket?.password) {
                promises.push(this.auth(RedisClient.commandOptions({ asap: true }), this.#options?.socket));
            }
            const resubscribePromise = this.#queue.resubscribe();
            if (resubscribePromise) {
                promises.push(resubscribePromise);
                this.#tick();
            }
            await Promise.all(promises);
        };
        return new socket_1.default(socketInitiator, this.#options?.socket)
            .on('data', data => this.#queue.parseResponse(data))
            .on('error', err => {
            this.emit('error', err);
            this.#queue.flushWaitingForReply(err);
        })
            .on('connect', () => this.emit('connect'))
            .on('ready', () => {
            this.emit('ready');
            this.#tick();
        })
            .on('reconnecting', () => this.emit('reconnecting'))
            .on('end', () => this.emit('end'));
    }
    #initiateQueue() {
        return new commands_queue_1.default(this.#options?.commandsQueueMaxLength, (encodedCommands) => this.#socket.write(encodedCommands));
    }
    #initiateMulti() {
        const executor = async (commands) => {
            const promise = Promise.all(commands.map(({ encodedCommand }) => {
                return this.#queue.addEncodedCommand(encodedCommand);
            }));
            this.#tick();
            return await promise;
        };
        const options = this.#options;
        return class extends multi_command_1.default {
            constructor() {
                super(executor, options);
            }
        };
    }
    #initiateModules() {
        if (!this.#options?.modules)
            return;
        for (const m of this.#options.modules) {
            for (const [name, command] of Object.entries(m)) {
                RedisClient.defineCommand(this, name, command);
                this.#Multi.defineCommand(this.#Multi, name, command);
            }
        }
    }
    #initiateScripts() {
        if (!this.#options?.scripts)
            return;
        for (const [name, script] of Object.entries(this.#options.scripts)) {
            this[name] = async function (...args) {
                const options = command_options_1.isCommandOptions(args[0]) && args[0];
                return script.transformReply(await this.executeScript(script, ...script.transformArguments(...(options ? args.slice(1) : args))));
            };
        }
    }
    async executeScript(script, args, options) {
        try {
            return await this.sendCommand([
                'EVALSHA',
                script.SHA,
                script.NUMBER_OF_KEYS.toString(),
                ...args
            ], options);
        }
        catch (err) {
            if (!err?.message?.startsWith?.('NOSCRIPT')) {
                throw err;
            }
            return await this.sendCommand([
                'EVAL',
                script.SCRIPT,
                script.NUMBER_OF_KEYS.toString(),
                ...args
            ], options);
        }
    }
    #legacyMode() {
        if (!this.#options?.legacyMode)
            return;
        this.#modern.sendCommand = this.sendCommand.bind(this);
        this.sendCommand = (...args) => {
            const options = command_options_1.isCommandOptions(args[0]) && args.shift(), callback = typeof args[args.length - 1] === 'function' && args.pop();
            this.#modern.sendCommand(args.flat(), options)
                .then((reply) => {
                if (!callback)
                    return;
                // https://github.com/NodeRedis/node-redis#commands:~:text=minimal%20parsing
                callback(null, reply);
            })
                .catch((err) => {
                if (!callback) {
                    this.emit('error', err);
                    return;
                }
                callback(err);
            });
        };
        for (const name of Object.keys(commands_1.default)) {
            this.#defineLegacyCommand(name);
        }
        // hard coded commands
        this.#defineLegacyCommand('SELECT');
        this.#defineLegacyCommand('select');
        this.#defineLegacyCommand('SUBSCRIBE');
        this.#defineLegacyCommand('subscribe');
        this.#defineLegacyCommand('PSUBSCRIBE');
        this.#defineLegacyCommand('pSubscribe');
        this.#defineLegacyCommand('UNSUBSCRIBE');
        this.#defineLegacyCommand('unsubscribe');
        this.#defineLegacyCommand('PUNSUBSCRIBE');
        this.#defineLegacyCommand('pUnsubscribe');
        if (this.#options?.modules) {
            for (const m of this.#options.modules) {
                for (const name of Object.keys(m)) {
                    this.#defineLegacyCommand(name);
                }
            }
        }
        if (this.#options?.scripts) {
            for (const name of Object.keys(this.#options.scripts)) {
                this.#defineLegacyCommand(name);
            }
        }
    }
    #defineLegacyCommand(name) {
        this.#modern[name] = this[name];
        this[name] = function (...args) {
            this.sendCommand(name, ...args);
        };
    }
    duplicate() {
        return RedisClient.create(this.#options);
    }
    async connect() {
        await this.#socket.connect();
    }
    async SELECT(options, db) {
        if (!command_options_1.isCommandOptions(options)) {
            db = options;
            options = null;
        }
        await this.sendCommand(['SELECT', db.toString()], options);
        this.#selectedDB = db;
    }
    select = this.SELECT;
    SUBSCRIBE(channels, listener) {
        return this.#subscribe(commands_queue_1.PubSubSubscribeCommands.SUBSCRIBE, channels, listener);
    }
    subscribe = this.SUBSCRIBE;
    PSUBSCRIBE(patterns, listener) {
        return this.#subscribe(commands_queue_1.PubSubSubscribeCommands.PSUBSCRIBE, patterns, listener);
    }
    pSubscribe = this.PSUBSCRIBE;
    #subscribe(command, channels, listener) {
        const promise = this.#queue.subscribe(command, channels, listener);
        this.#tick();
        return promise;
    }
    UNSUBSCRIBE(channels, listener) {
        return this.#unsubscribe(commands_queue_1.PubSubUnsubscribeCommands.UNSUBSCRIBE, channels, listener);
    }
    unsubscribe = this.UNSUBSCRIBE;
    PUNSUBSCRIBE(patterns, listener) {
        return this.#unsubscribe(commands_queue_1.PubSubUnsubscribeCommands.PUNSUBSCRIBE, patterns, listener);
    }
    pUnsubscribe = this.PUNSUBSCRIBE;
    #unsubscribe(command, channels, listener) {
        const promise = this.#queue.unsubscribe(command, channels, listener);
        this.#tick();
        return promise;
    }
    async sendCommand(args, options) {
        if (options?.duplicateConnection) {
            const duplicate = this.duplicate();
            await duplicate.connect();
            try {
                return await duplicate.sendCommand(args, {
                    ...options,
                    duplicateConnection: false
                });
            }
            finally {
                await duplicate.disconnect();
            }
        }
        const promise = this.#queue.addCommand(args, options);
        this.#tick();
        return await promise;
    }
    multi() {
        return new this.#Multi();
    }
    async *scanIterator(options) {
        let cursor = 0;
        do {
            const reply = await this.scan(cursor, options);
            cursor = reply.cursor;
            for (const key of reply.keys) {
                yield key;
            }
        } while (cursor !== 0);
    }
    async *sScanIterator(key, options) {
        let cursor = 0;
        do {
            const reply = await this.sScan(key, cursor, options);
            cursor = reply.cursor;
            for (const key of reply.keys) {
                yield key;
            }
        } while (cursor !== 0);
    }
    async *zScanIterator(key, options) {
        let cursor = 0;
        do {
            const reply = await this.zScan(key, cursor, options);
            cursor = reply.cursor;
            for (const member of reply.members) {
                yield member;
            }
        } while (cursor !== 0);
    }
    disconnect() {
        this.#queue.flushAll(new Error('Disconnecting'));
        return this.#socket.disconnect();
    }
    #tick() {
        const { chunkRecommendedSize } = this.#socket;
        if (!chunkRecommendedSize) {
            return;
        }
        // TODO: batch using process.nextTick? maybe socket.setNoDelay(false)?
        const isBuffering = this.#queue.executeChunk(chunkRecommendedSize);
        if (isBuffering === true) {
            this.#socket.once('drain', () => this.#tick());
        }
        else if (isBuffering === false) {
            this.#tick();
        }
    }
}
exports.default = RedisClient;
for (const [name, command] of Object.entries(commands_1.default)) {
    RedisClient.defineCommand(RedisClient.prototype, name, command);
}
