"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const cluster_1 = __importDefault(require("./cluster"));
const lua_script_1 = require("./lua-script");
const test_utils_1 = require("./test-utils");
describe('Cluster', () => {
    it('sendCommand', async () => {
        const cluster = cluster_1.default.create({
            rootNodes: test_utils_1.TEST_REDIS_CLUSTERES[test_utils_1.TestRedisClusters.OPEN],
            useReplicas: true
        });
        await cluster.connect();
        await cluster.ping();
        await cluster.set('a', 'b');
        await cluster.set('a{a}', 'bb');
        await cluster.set('aa', 'bb');
        await cluster.get('aa');
        await cluster.get('aa');
        await cluster.get('aa');
        await cluster.get('aa');
        await cluster.disconnect();
    });
    it('scripts', async () => {
        const cluster = cluster_1.default.create({
            rootNodes: test_utils_1.TEST_REDIS_CLUSTERES[test_utils_1.TestRedisClusters.OPEN],
            scripts: {
                add: lua_script_1.defineScript({
                    NUMBER_OF_KEYS: 0,
                    SCRIPT: 'return ARGV[1] + 1;',
                    transformArguments(number) {
                        assert_1.strict.equal(number, 1);
                        return [number.toString()];
                    },
                    transformReply(reply) {
                        assert_1.strict.equal(reply, 2);
                        return reply;
                    }
                })
            }
        });
        await cluster.connect();
        try {
            assert_1.strict.equal(await cluster.add(1), 2);
        }
        finally {
            await cluster.disconnect();
        }
    });
});
