"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const BITFIELD_1 = require("./BITFIELD");
describe('BITFIELD', () => {
    describe('transformArguments', () => {
        it('simple', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key'), ['BITFIELD', 'key']);
        });
        it('with GET', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key', {
                GET: {
                    type: 'i8',
                    offset: 0
                }
            }), ['BITFIELD', 'key', 'GET', 'i8', '0']);
        });
        it('with SET', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key', {
                SET: {
                    type: 'i8',
                    offset: 0,
                    value: 0
                }
            }), ['BITFIELD', 'key', 'SET', 'i8', '0', '0']);
        });
        it('with INCRBY', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key', {
                INCRBY: {
                    type: 'i8',
                    offset: 0,
                    increment: 0
                }
            }), ['BITFIELD', 'key', 'INCRBY', 'i8', '0', '0']);
        });
        it('with OVERFLOW', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key', {
                OVERFLOW: 'WRAP'
            }), ['BITFIELD', 'key', 'OVERFLOW', 'WRAP']);
        });
        it('with GET, SET, INCRBY, OVERFLOW', () => {
            assert_1.strict.deepEqual(BITFIELD_1.transformArguments('key', {
                GET: {
                    type: 'i8',
                    offset: 0
                },
                SET: {
                    type: 'i8',
                    offset: 0,
                    value: 0
                },
                INCRBY: {
                    type: 'i8',
                    offset: 0,
                    increment: 0
                },
                OVERFLOW: 'WRAP'
            }), ['BITFIELD', 'key', 'GET', 'i8', '0', 'SET', 'i8', '0', '0', 'INCRBY', 'i8', '0', '0', 'OVERFLOW', 'WRAP']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.bitField', async (client) => {
        assert_1.strict.deepEqual(await client.bitField('key'), []);
    });
});
