"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const BLPOP_1 = require("./BLPOP");
const client_1 = __importDefault(require("../client"));
describe('BLPOP', () => {
    describe('transformArguments', () => {
        it('single', () => {
            assert_1.strict.deepEqual(BLPOP_1.transformArguments('key', 0), ['BLPOP', 'key', '0']);
        });
        it('multiple', () => {
            assert_1.strict.deepEqual(BLPOP_1.transformArguments(['key1', 'key2'], 0), ['BLPOP', 'key1', 'key2', '0']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.blPop', async (client) => {
        const [popReply] = await Promise.all([
            client.blPop(client_1.default.commandOptions({
                duplicateConnection: true
            }), 'key', 0),
            client.lPush('key', 'element')
        ]);
        assert_1.strict.deepEqual(popReply, {
            key: 'key',
            element: 'element'
        });
    });
    test_utils_1.itWithCluster(test_utils_1.TestRedisClusters.OPEN, 'cluster.blPop', async (cluster) => {
        const [popReply] = await Promise.all([
            cluster.blPop(client_1.default.commandOptions({
                duplicateConnection: true
            }), 'key', 0),
            cluster.lPush('key', 'element')
        ]);
        assert_1.strict.deepEqual(popReply, {
            key: 'key',
            element: 'element'
        });
    });
});
