"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const CLUSTER_NODES_1 = require("./CLUSTER_NODES");
describe('CLUSTER NODES', () => {
    it('transformArguments', () => {
        assert_1.strict.deepEqual(CLUSTER_NODES_1.transformArguments(), ['CLUSTER', 'NODES']);
    });
    describe('transformReply', () => {
        it('simple', () => {
            assert_1.strict.deepEqual(CLUSTER_NODES_1.transformReply([
                'master 127.0.0.1:30001@31001 myself,master - 0 0 1 connected 0-16384',
                'slave 127.0.0.1:30002@31002 slave master 0 0 1 connected',
                ''
            ].join('\n')), [{
                    id: 'master',
                    url: '127.0.0.1:30001@31001',
                    host: '127.0.0.1',
                    port: 30001,
                    cport: 31001,
                    flags: ['myself', 'master'],
                    pingSent: 0,
                    pongRecv: 0,
                    configEpoch: 1,
                    linkState: CLUSTER_NODES_1.RedisClusterNodeLinkStates.CONNECTED,
                    slots: [{
                            from: 0,
                            to: 16384
                        }],
                    replicas: [{
                            id: 'slave',
                            url: '127.0.0.1:30002@31002',
                            host: '127.0.0.1',
                            port: 30002,
                            cport: 31002,
                            flags: ['slave'],
                            pingSent: 0,
                            pongRecv: 0,
                            configEpoch: 1,
                            linkState: CLUSTER_NODES_1.RedisClusterNodeLinkStates.CONNECTED
                        }]
                }]);
        });
        it.skip('with importing slots', () => {
            assert_1.strict.deepEqual(CLUSTER_NODES_1.transformReply('id 127.0.0.1:30001@31001 master - 0 0 0 connected 0-<-16384\n'), [{
                    id: 'id',
                    url: '127.0.0.1:30001@31001',
                    host: '127.0.0.1',
                    port: 30001,
                    cport: 31001,
                    flags: ['master'],
                    pingSent: 0,
                    pongRecv: 0,
                    configEpoch: 0,
                    linkState: CLUSTER_NODES_1.RedisClusterNodeLinkStates.CONNECTED,
                    slots: [],
                    replicas: []
                }]);
        });
        it.skip('with migrating slots', () => {
            assert_1.strict.deepEqual(CLUSTER_NODES_1.transformReply('id 127.0.0.1:30001@31001 master - 0 0 0 connected 0->-16384\n'), [{
                    id: 'id',
                    url: '127.0.0.1:30001@31001',
                    host: '127.0.0.1',
                    port: 30001,
                    cport: 31001,
                    flags: ['master'],
                    pingSent: 0,
                    pongRecv: 0,
                    configEpoch: 0,
                    linkState: CLUSTER_NODES_1.RedisClusterNodeLinkStates.CONNECTED,
                    slots: [],
                    replicas: []
                }]);
        });
    });
});
