"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const COPY_1 = require("./COPY");
describe('COPY', () => {
    describe('transformArguments', () => {
        it('simple', () => {
            assert_1.strict.deepEqual(COPY_1.transformArguments('source', 'destination'), ['COPY', 'source', 'destination']);
        });
        it('with destination DB flag', () => {
            assert_1.strict.deepEqual(COPY_1.transformArguments('source', 'destination', {
                destinationDb: 1
            }), ['COPY', 'source', 'destination', 'DB', '1']);
        });
        it('with replace flag', () => {
            assert_1.strict.deepEqual(COPY_1.transformArguments('source', 'destination', {
                replace: true
            }), ['COPY', 'source', 'destination', 'REPLACE']);
        });
        it('with both flags', () => {
            assert_1.strict.deepEqual(COPY_1.transformArguments('source', 'destination', {
                destinationDb: 1,
                replace: true
            }), ['COPY', 'source', 'destination', 'DB', '1', 'REPLACE']);
        });
    });
    describe('transformReply', () => {
        it('0', () => {
            assert_1.strict.equal(COPY_1.transformReply(0), false);
        });
        it('1', () => {
            assert_1.strict.equal(COPY_1.transformReply(1), true);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.copy', async (client) => {
        assert_1.strict.equal(await client.copy('source', 'destination'), false);
    });
});
