"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const SCAN_1 = require("./SCAN");
describe('SCAN', () => {
    describe('transformArguments', () => {
        it('cusror only', () => {
            assert_1.strict.deepEqual(SCAN_1.transformArguments(0), ['SCAN', '0']);
        });
        it('with MATCH', () => {
            assert_1.strict.deepEqual(SCAN_1.transformArguments(0, {
                MATCH: 'pattern'
            }), ['SCAN', '0', 'MATCH', 'pattern']);
        });
        it('with COUNT', () => {
            assert_1.strict.deepEqual(SCAN_1.transformArguments(0, {
                COUNT: 1
            }), ['SCAN', '0', 'COUNT', '1']);
        });
        it('with TYPE', () => {
            assert_1.strict.deepEqual(SCAN_1.transformArguments(0, {
                TYPE: 'stream'
            }), ['SCAN', '0', 'TYPE', 'stream']);
        });
        it('with MATCH & COUNT & TYPE', () => {
            assert_1.strict.deepEqual(SCAN_1.transformArguments(0, {
                MATCH: 'pattern',
                COUNT: 1,
                TYPE: 'stream'
            }), ['SCAN', '0', 'MATCH', 'pattern', 'COUNT', '1', 'TYPE', 'stream']);
        });
    });
    describe('transformReply', () => {
        it('without keys', () => {
            assert_1.strict.deepEqual(SCAN_1.transformReply(['0', []]), {
                cursor: 0,
                keys: []
            });
        });
        it('with keys', () => {
            assert_1.strict.deepEqual(SCAN_1.transformReply(['0', ['key']]), {
                cursor: 0,
                keys: ['key']
            });
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.scan', async (client) => {
        assert_1.strict.deepEqual(await client.scan(0), {
            cursor: 0,
            keys: []
        });
    });
});
