"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const SORT_1 = require("./SORT");
describe('SORT', () => {
    describe('transformArguments', () => {
        it('simple', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key'), ['SORT', 'key']);
        });
        it('with BY', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                BY: 'pattern'
            }), ['SORT', 'key', 'BY', 'pattern']);
        });
        it('with LIMIT', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                LIMIT: {
                    offset: 0,
                    count: 1
                }
            }), ['SORT', 'key', 'LIMIT', '0', '1']);
        });
        describe('with GET', () => {
            it('string', () => {
                assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                    GET: 'pattern'
                }), ['SORT', 'key', 'GET', 'pattern']);
            });
            it('array', () => {
                assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                    GET: ['1', '2']
                }), ['SORT', 'key', 'GET', '1', 'GET', '2']);
            });
        });
        it('with DIRECTION', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                DIRECTION: 'ASC'
            }), ['SORT', 'key', 'ASC']);
        });
        it('with ALPHA', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                ALPHA: true
            }), ['SORT', 'key', 'ALPHA']);
        });
        it('with STORE', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                STORE: 'destination'
            }), ['SORT', 'key', 'STORE', 'destination']);
        });
        it('with BY, LIMIT, GET, DIRECTION, ALPHA, STORE', () => {
            assert_1.strict.deepEqual(SORT_1.transformArguments('key', {
                BY: 'pattern',
                LIMIT: {
                    offset: 0,
                    count: 1
                },
                GET: 'pattern',
                DIRECTION: 'ASC',
                ALPHA: true,
                STORE: 'destination'
            }), ['SORT', 'key', 'BY', 'pattern', 'LIMIT', '0', '1', 'GET', 'pattern', 'ASC', 'ALPHA', 'STORE', 'destination']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.sort', async (client) => {
        assert_1.strict.deepEqual(await client.sort('key'), []);
    });
});
