"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const XADD_1 = require("./XADD");
describe('XADD', () => {
    describe('transformArguments', () => {
        it('single field', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }), ['XADD', 'key', '*', 'field', 'value']);
        });
        it('multiple fields', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                '1': 'I',
                '2': 'II'
            }), ['XADD', 'key', '*', '1', 'I', '2', 'II']);
        });
        it('with NOMKSTREAM', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                NOMKSTREAM: true
            }), ['XADD', 'key', 'NOMKSTREAM', '*', 'field', 'value']);
        });
        it('with TRIM', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                TRIM: {
                    threshold: 1000
                }
            }), ['XADD', 'key', '1000', '*', 'field', 'value']);
        });
        it('with TRIM.strategy', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                TRIM: {
                    strategy: 'MAXLEN',
                    threshold: 1000
                }
            }), ['XADD', 'key', 'MAXLEN', '1000', '*', 'field', 'value']);
        });
        it('with TRIM.strategyModifier', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                TRIM: {
                    strategyModifier: '=',
                    threshold: 1000
                }
            }), ['XADD', 'key', '=', '1000', '*', 'field', 'value']);
        });
        it('with TRIM.limit', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                TRIM: {
                    threshold: 1000,
                    limit: 1
                }
            }), ['XADD', 'key', '1000', 'LIMIT', '1', '*', 'field', 'value']);
        });
        it('with NOMKSTREAM, TRIM, TRIM.*', () => {
            assert_1.strict.deepEqual(XADD_1.transformArguments('key', '*', {
                field: 'value'
            }, {
                NOMKSTREAM: true,
                TRIM: {
                    strategy: 'MAXLEN',
                    strategyModifier: '=',
                    threshold: 1000,
                    limit: 1
                }
            }), ['XADD', 'key', 'NOMKSTREAM', 'MAXLEN', '=', '1000', 'LIMIT', '1', '*', 'field', 'value']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.xAdd', async (client) => {
        assert_1.strict.equal(typeof await client.xAdd('key', '*', {
            field: 'value'
        }), 'string');
    });
});
