"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const XCLAIM_1 = require("./XCLAIM");
describe('XCLAIM', () => {
    describe('transformArguments', () => {
        it('single id (string)', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0'), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0']);
        });
        it('multiple ids (array)', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, ['0-0', '1-0']), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', '1-0']);
        });
        it('with IDLE', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                IDLE: 1
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'IDLE', '1']);
        });
        it('with TIME (number)', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                TIME: 1
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'TIME', '1']);
        });
        it('with TIME (date)', () => {
            const d = new Date();
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                TIME: d
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'TIME', d.getTime().toString()]);
        });
        it('with RETRYCOUNT', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                RETRYCOUNT: 1
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'RETRYCOUNT', '1']);
        });
        it('with FORCE', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                FORCE: true
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'FORCE']);
        });
        it('with IDLE, TIME, RETRYCOUNT, FORCE, JUSTID', () => {
            assert_1.strict.deepEqual(XCLAIM_1.transformArguments('key', 'group', 'consumer', 1, '0-0', {
                IDLE: 1,
                TIME: 1,
                RETRYCOUNT: 1,
                FORCE: true
            }), ['XCLAIM', 'key', 'group', 'consumer', '1', '0-0', 'IDLE', '1', 'TIME', '1', 'RETRYCOUNT', '1', 'FORCE']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.xClaim', async (client) => {
        await Promise.all([
            client.xGroupCreate('key', 'group', '$', {
                MKSTREAM: true
            }),
            client.xGroupCreateConsumer('key', 'group', 'consumer'),
        ]);
        assert_1.strict.deepEqual(await client.xClaim('key', 'group', 'consumer', 1, '0-0'), []);
    });
});
