"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const XINFO_STREAM_1 = require("./XINFO_STREAM");
describe('XINFO STREAM', () => {
    it('transformArguments', () => {
        assert_1.strict.deepEqual(XINFO_STREAM_1.transformArguments('key'), ['XINFO', 'STREAM', 'key']);
    });
    it('transformReply', () => {
        assert_1.strict.deepEqual(XINFO_STREAM_1.transformReply([
            'length', 2,
            'radix-tree-keys', 1,
            'radix-tree-nodes', 2,
            'last-generated-id', '1538385846314-0',
            'groups', 2,
            'first-entry', ['1538385820729-0', ['foo', 'bar']],
            'last-entry', ['1538385846314-0', ['field', 'value']]
        ]), {
            length: 2,
            radixTreeKeys: 1,
            radixTreeNodes: 2,
            groups: 2,
            lastGeneratedId: '1538385846314-0',
            firstEntry: {
                id: '1538385820729-0',
                message: Object.create(null, {
                    foo: {
                        value: 'bar',
                        configurable: true,
                        enumerable: true
                    }
                })
            },
            lastEntry: {
                id: '1538385846314-0',
                message: Object.create(null, {
                    field: {
                        value: 'value',
                        configurable: true,
                        enumerable: true
                    }
                })
            }
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.xInfoStream', async (client) => {
        await client.xGroupCreate('key', 'group', '$', {
            MKSTREAM: true
        });
        assert_1.strict.deepEqual(await client.xInfoStream('key'), {
            length: 0,
            radixTreeKeys: 0,
            radixTreeNodes: 1,
            groups: 1,
            lastGeneratedId: '0-0',
            firstEntry: null,
            lastEntry: null
        });
    });
});
