"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const XREAD_1 = require("./XREAD");
describe('XREAD', () => {
    describe('transformArguments', () => {
        it('single stream', () => {
            assert_1.strict.deepEqual(XREAD_1.transformArguments({
                key: 'key',
                id: '0'
            }), ['XREAD', 'STREAMS', 'key', '0']);
        });
        it('multiple streams', () => {
            assert_1.strict.deepEqual(XREAD_1.transformArguments([{
                    key: '1',
                    id: '0'
                }, {
                    key: '2',
                    id: '0'
                }]), ['XREAD', 'STREAMS', '1', '2', '0', '0']);
        });
        it('with COUNT', () => {
            assert_1.strict.deepEqual(XREAD_1.transformArguments({
                key: 'key',
                id: '0'
            }, {
                COUNT: 1
            }), ['XREAD', 'COUNT', '1', 'STREAMS', 'key', '0']);
        });
        it('with BLOCK', () => {
            assert_1.strict.deepEqual(XREAD_1.transformArguments({
                key: 'key',
                id: '0'
            }, {
                BLOCK: 0
            }), ['XREAD', 'BLOCK', '0', 'STREAMS', 'key', '0']);
        });
        it('with COUNT, BLOCK', () => {
            assert_1.strict.deepEqual(XREAD_1.transformArguments({
                key: 'key',
                id: '0'
            }, {
                COUNT: 1,
                BLOCK: 0
            }), ['XREAD', 'COUNT', '1', 'BLOCK', '0', 'STREAMS', 'key', '0']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.xRead', async (client) => {
        assert_1.strict.equal(await client.xRead({
            key: 'key',
            id: '0'
        }), null);
    });
    test_utils_1.itWithCluster(test_utils_1.TestRedisClusters.OPEN, 'cluster.xRead', async (cluster) => {
        assert_1.strict.equal(await cluster.xRead({
            key: 'key',
            id: '0'
        }), null);
    });
});
