"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const XREADGROUP_1 = require("./XREADGROUP");
describe('XREADGROUP', () => {
    describe('transformArguments', () => {
        it('single stream', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', {
                key: 'key',
                id: '0'
            }), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'STREAMS', 'key', '0']);
        });
        it('multiple streams', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', [{
                    key: '1',
                    id: '0'
                }, {
                    key: '2',
                    id: '0'
                }]), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'STREAMS', '1', '2', '0', '0']);
        });
        it('with COUNT', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', {
                key: 'key',
                id: '0'
            }, {
                COUNT: 1
            }), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'COUNT', '1', 'STREAMS', 'key', '0']);
        });
        it('with BLOCK', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', {
                key: 'key',
                id: '0'
            }, {
                BLOCK: 0
            }), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'BLOCK', '0', 'STREAMS', 'key', '0']);
        });
        it('with NOACK', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', {
                key: 'key',
                id: '0'
            }, {
                NOACK: true
            }), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'NOACK', 'STREAMS', 'key', '0']);
        });
        it('with COUNT, BLOCK, NOACK', () => {
            assert_1.strict.deepEqual(XREADGROUP_1.transformArguments('group', 'consumer', {
                key: 'key',
                id: '0'
            }, {
                COUNT: 1,
                BLOCK: 0,
                NOACK: true
            }), ['XREADGROUP', 'GROUP', 'group', 'consumer', 'COUNT', '1', 'BLOCK', '0', 'NOACK', 'STREAMS', 'key', '0']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.xReadGroup', async (client) => {
        const [, readGroupReply] = await Promise.all([
            client.xGroupCreate('key', 'group', '$', {
                MKSTREAM: true
            }),
            client.xReadGroup('group', 'consumer', {
                key: 'key',
                id: '0'
            })
        ]);
        assert_1.strict.deepEqual(readGroupReply, [{
                name: 'key',
                messages: []
            }]);
    });
    test_utils_1.itWithCluster(test_utils_1.TestRedisClusters.OPEN, 'cluster.xReadGroup', async (cluster) => {
        const [, readGroupReply] = await Promise.all([
            cluster.xGroupCreate('key', 'group', '$', {
                MKSTREAM: true
            }),
            cluster.xReadGroup('group', 'consumer', {
                key: 'key',
                id: '0'
            })
        ]);
        assert_1.strict.deepEqual(readGroupReply, [{
                name: 'key',
                messages: []
            }]);
    });
});
