"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const ZADD_1 = require("./ZADD");
describe('ZADD', () => {
    describe('transformArguments', () => {
        it('single member', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }), ['ZADD', 'key', '1', '1']);
        });
        it('multiple members', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', [{
                    value: '1',
                    score: 1
                }, {
                    value: '2',
                    score: 2
                }]), ['ZADD', 'key', '1', '1', '2', '2']);
        });
        it('with NX', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                NX: true
            }), ['ZADD', 'key', 'NX', '1', '1']);
        });
        it('with XX', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                XX: true
            }), ['ZADD', 'key', 'XX', '1', '1']);
        });
        it('with GT', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                GT: true
            }), ['ZADD', 'key', 'GT', '1', '1']);
        });
        it('with LT', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                LT: true
            }), ['ZADD', 'key', 'LT', '1', '1']);
        });
        it('with CH', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                CH: true
            }), ['ZADD', 'key', 'CH', '1', '1']);
        });
        it('with INCR', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                INCR: true
            }), ['ZADD', 'key', 'INCR', '1', '1']);
        });
        it('with XX, GT, CH, INCR', () => {
            assert_1.strict.deepEqual(ZADD_1.transformArguments('key', {
                value: '1',
                score: 1
            }, {
                XX: true,
                GT: true,
                CH: true,
                INCR: true
            }), ['ZADD', 'key', 'XX', 'GT', 'CH', 'INCR', '1', '1']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.zAdd', async (client) => {
        assert_1.strict.equal(await client.zAdd('key', {
            value: '1',
            score: 1
        }), 1);
    });
});
