"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const ZRANGESTORE_1 = require("./ZRANGESTORE");
describe('ZRANGESTORE', () => {
    describe('transformArguments', () => {
        it('simple', () => {
            assert_1.strict.deepEqual(ZRANGESTORE_1.transformArguments('dst', 'src', 0, 1), ['ZRANGESTORE', 'dst', 'src', '0', '1']);
        });
        it('with BY', () => {
            assert_1.strict.deepEqual(ZRANGESTORE_1.transformArguments('dst', 'src', 0, 1, {
                BY: 'SCORE'
            }), ['ZRANGESTORE', 'dst', 'src', '0', '1', 'BYSCORE']);
        });
        it('with REV', () => {
            assert_1.strict.deepEqual(ZRANGESTORE_1.transformArguments('dst', 'src', 0, 1, {
                REV: true
            }), ['ZRANGESTORE', 'dst', 'src', '0', '1', 'REV']);
        });
        it('with LIMIT', () => {
            assert_1.strict.deepEqual(ZRANGESTORE_1.transformArguments('dst', 'src', 0, 1, {
                LIMIT: {
                    offset: 0,
                    count: 1
                }
            }), ['ZRANGESTORE', 'dst', 'src', '0', '1', 'LIMIT', '0', '1']);
        });
        it('with BY & REV & LIMIT', () => {
            assert_1.strict.deepEqual(ZRANGESTORE_1.transformArguments('dst', 'src', 0, 1, {
                BY: 'SCORE',
                REV: true,
                LIMIT: {
                    offset: 0,
                    count: 1
                },
                WITHSCORES: true
            }), ['ZRANGESTORE', 'dst', 'src', '0', '1', 'BYSCORE', 'REV', 'LIMIT', '0', '1', 'WITHSCORES']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.zRangeStore', async (client) => {
        assert_1.strict.equal(await client.zRangeStore('dst', 'src', 0, 1), 0);
    });
});
