"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const test_utils_1 = require("../test-utils");
const ZUNIONSTORE_1 = require("./ZUNIONSTORE");
describe('ZUNIONSTORE', () => {
    describe('transformArguments', () => {
        it('key (string)', () => {
            assert_1.strict.deepEqual(ZUNIONSTORE_1.transformArguments('destination', 'key'), ['ZUNIONSTORE', 'destination', '1', 'key']);
        });
        it('keys (array)', () => {
            assert_1.strict.deepEqual(ZUNIONSTORE_1.transformArguments('destination', ['1', '2']), ['ZUNIONSTORE', 'destination', '2', '1', '2']);
        });
        it('with WEIGHTS', () => {
            assert_1.strict.deepEqual(ZUNIONSTORE_1.transformArguments('destination', 'key', {
                WEIGHTS: [1]
            }), ['ZUNIONSTORE', 'destination', '1', 'key', 'WEIGHTS', '1']);
        });
        it('with AGGREGATE', () => {
            assert_1.strict.deepEqual(ZUNIONSTORE_1.transformArguments('destination', 'key', {
                AGGREGATE: 'SUM'
            }), ['ZUNIONSTORE', 'destination', '1', 'key', 'AGGREGATE', 'SUM']);
        });
        it('with WEIGHTS, AGGREGATE', () => {
            assert_1.strict.deepEqual(ZUNIONSTORE_1.transformArguments('destination', 'key', {
                WEIGHTS: [1],
                AGGREGATE: 'SUM'
            }), ['ZUNIONSTORE', 'destination', '1', 'key', 'WEIGHTS', '1', 'AGGREGATE', 'SUM']);
        });
    });
    test_utils_1.itWithClient(test_utils_1.TestRedisServers.OPEN, 'client.zUnionStore', async (client) => {
        assert_1.strict.equal(await client.zUnionStore('destination', 'key'), 0);
    });
});
