import COMMANDS from './commands';
import { RedisCommand, RedisModules, RedisReply } from './commands';
import { RedisLuaScripts } from './lua-script';
import { RedisClientOptions } from './client';
declare type RedisMultiCommandSignature<C extends RedisCommand, M extends RedisModules, S extends RedisLuaScripts> = (...args: Parameters<C['transformArguments']>) => RedisMultiCommandType<M, S>;
declare type WithCommands<M extends RedisModules, S extends RedisLuaScripts> = {
    [P in keyof typeof COMMANDS]: RedisMultiCommandSignature<(typeof COMMANDS)[P], M, S>;
};
declare type WithModules<M extends RedisModules, S extends RedisLuaScripts> = {
    [P in keyof M[number]]: RedisMultiCommandSignature<M[number][P], M, S>;
};
declare type WithScripts<M extends RedisModules, S extends RedisLuaScripts> = {
    [P in keyof S]: RedisMultiCommandSignature<S[P], M, S>;
};
export declare type RedisMultiCommandType<M extends RedisModules, S extends RedisLuaScripts> = RedisMultiCommand & WithCommands<M, S> & WithModules<M, S> & WithScripts<M, S>;
export interface MultiQueuedCommand {
    encodedCommand: string;
    transformReply?: RedisCommand['transformReply'];
}
export declare type RedisMultiExecutor = (queue: Array<MultiQueuedCommand>, chainId?: Symbol) => Promise<Array<RedisReply>>;
export default class RedisMultiCommand<M extends RedisModules = RedisModules, S extends RedisLuaScripts = RedisLuaScripts> {
    #private;
    static defineCommand(on: any, name: string, command: RedisCommand): void;
    static create<M extends RedisModules, S extends RedisLuaScripts>(executor: RedisMultiExecutor, clientOptions?: RedisClientOptions<M, S>): RedisMultiCommandType<M, S>;
    get modern(): Record<string, Function>;
    constructor(executor: RedisMultiExecutor, clientOptions?: RedisClientOptions<M, S>);
    addCommand(args: Array<string>, transformReply?: RedisCommand['transformReply']): this;
    exec(execAsPipeline?: boolean): Promise<Array<unknown>>;
    execAsPipeline(): Promise<Array<unknown>>;
}
export {};
